'use strict';exports.__esModule = true;

var _fs = require('fs');var _fs2 = _interopRequireDefault(_fs);
var _path = require('path');var _path2 = _interopRequireDefault(_path);
var _lodash = require('lodash');var _lodash2 = _interopRequireDefault(_lodash);
var _requireAll = require('require-all');var _requireAll2 = _interopRequireDefault(_requireAll);function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { default: obj };}function _classCallCheck(instance, Constructor) {if (!(instance instanceof Constructor)) {throw new TypeError("Cannot call a class as a function");}} /* eslint-disable global-require */var

SpurConfig = function () {

  function SpurConfig(folderPath, configName) {_classCallCheck(this, SpurConfig);
    this.folderPath = folderPath;
    this.configName = configName || SpurConfig.getEnv();
    this.baseObject = {};
    this.defaultPluginsPath = _path2.default.join(__dirname, './plugins');
    this.customPluginsPath = _path2.default.join(this.folderPath, '/plugins');
    this.plugins = {};
  }SpurConfig.

  load = function load(folderPath, configName) {
    var spurConfig = new SpurConfig(folderPath, configName);
    spurConfig.load();
    return spurConfig;
  };SpurConfig.

  loadEnv = function loadEnv(folderPath) {
    this.load(folderPath, this.getEnv());
  };SpurConfig.

  getEnv = function getEnv() {
    return process.env.NODE_ENV || 'development';
  };SpurConfig.prototype.

  load = function load() {
    try {
      this.loadPlugins();
      this.configFile = require(_path2.default.join(this.folderPath, this.configName));
      this.configFile.apply(this.plugins);
      return this.baseObject;
    } catch (e) {
      /* eslint-disable no-console */
      console.error('Couldn\'t load config ' + this.folderPath + '/' + this.configName);
      console.error(e.stack);
      /* eslint-enable no-console */
      throw e;
    }
  };SpurConfig.prototype.

  loadPlugins = function loadPlugins() {
    this.loadPluginsFromPath(this.defaultPluginsPath);
    this.loadPluginsFromPath(this.customPluginsPath);
  };SpurConfig.prototype.

  loadPluginsFromPath = function loadPluginsFromPath(folderPath) {
    if (_fs2.default.existsSync(folderPath)) {
      var pluginsObject = (0, _requireAll2.default)({
        dirname: folderPath,
        filter: /(.+)\.(js|coffee)$/ });

      this.loadPluginsByObject(pluginsObject);
    }
  };SpurConfig.prototype.

  loadPluginsByObject = function loadPluginsByObject(pluginsObject) {var _this = this;
    _lodash2.default.forEach(pluginsObject, function (plugin, pluginName) {
      if (_lodash2.default.isFunction(plugin)) {
        _this.plugins[pluginName] = plugin.bind(_this);
      } else {
        _this.loadPluginsByObject(plugin);
      }
    });
  };SpurConfig.prototype.

  deepExtend = function deepExtend(obj1, obj2) {
    var ob1 = obj1 || {};
    var ob2 = obj2 || {};
    this.baseObject = _lodash2.default.merge({}, this.baseObject, ob1, ob2);
  };SpurConfig.prototype.

  getConfig = function getConfig() {
    return this.baseObject;
  };SpurConfig.prototype.

  loadConfig = function loadConfig(configName) {
    return SpurConfig.load(this.folderPath, configName).getConfig();
  };SpurConfig.prototype.

  toJSONString = function toJSONString() {
    return JSON.stringify(this.baseObject, null, 2);
  };return SpurConfig;}();exports.default =



SpurConfig;module.exports = exports['default'];
//# sourceMappingURL=SpurConfig.js.map